/**
 * Copyright (c) 2013-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api;

import org.ow2.petals.clientserverapi.system.logging.LoggingService;
import org.ow2.petals.jmx.api.api.exception.LoggerServiceErrorException;

/**
 * Interface of the JMX Logger service.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface LoggerServiceClient extends LoggingService {

    /**
     * Name of the associated MBean containing additional method provided by Petals ESB
     */
    public static final String LOGGER_SERVICE_MBEAN_NAME = "PetalsLogger";

    /**
     * Set level value for a specified logger
     * 
     * @param logger
     *            The logger name, where the value should be assigned.
     * @param level
     *            The {@link String} value of the log level that must be set.
     * @throws LoggerServiceErrorException
     *             if an error occurs while performing the action
     */
    public void setLoggerLevel(final String logger, final String level) throws LoggerServiceErrorException;

    /**
     * Get level value for a specified logger
     * 
     * @param logger
     *            The logger name, where the value should be assigned.
     * @return The log level of the logger
     * @throws LoggerServiceErrorException
     *             if an error occurs while performing the action
     */
    public String getLoggerLevel(final String logger) throws LoggerServiceErrorException;
}
