/**
 * Copyright (c) 2013-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api;

import javax.management.openmbean.CompositeDataSupport;

import org.ow2.petals.jmx.api.api.exception.SystemMonitoringServiceErrorException;

/**
 * Interface of the JMX System Monitoring service.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface SystemMonitoringServiceClient {

    /**
     * Get heap memory usage
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public CompositeDataSupport getHeapMemoryUsage() throws SystemMonitoringServiceErrorException;

    /**
     * Get heap memory usage
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public int getPendingObjects() throws SystemMonitoringServiceErrorException;

    /**
     * Get Peak thread count
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public int getPeakThreadCount() throws SystemMonitoringServiceErrorException;

    /**
     * Get Daemon thread count
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public int getDaemonThreadCount() throws SystemMonitoringServiceErrorException;

    /**
     * Get thread count
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public int getThreadCount() throws SystemMonitoringServiceErrorException;

    /**
     * Get the total started thread count
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public long getTotalStartedThreadCount() throws SystemMonitoringServiceErrorException;

    /**
     * Get the available processors
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public int getAvailableProcessors() throws SystemMonitoringServiceErrorException;

    /**
     * Get the up time
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public long getUptime() throws SystemMonitoringServiceErrorException;

    /**
     * Get the loaded class count
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public int getLoadedClassCount() throws SystemMonitoringServiceErrorException;

    /**
     * Get the total loaded class count
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public long getTotalLoadedClassCount() throws SystemMonitoringServiceErrorException;

    /**
     * Get the unloaded class count
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public long getUnloadedClassCount() throws SystemMonitoringServiceErrorException;

    /**
     * Get the process cpu time
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public long getProcessCpuTime() throws SystemMonitoringServiceErrorException;

    /**
     * Get the total physical mem size
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public long getTotalPhysicalMemorySize() throws SystemMonitoringServiceErrorException;

    /**
     * Get the free physical memory size
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public long getFreePhysicalMemorySize() throws SystemMonitoringServiceErrorException;

    /**
     * Get the committed physical memory size
     * 
     * @throws SystemMonitoringServiceErrorException
     */
    public long getCommittedVirtualMemorySize() throws SystemMonitoringServiceErrorException;

}
