/**
 * Copyright (c) 2013-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api.configuration.component;

import java.util.Map;

import javax.management.MBeanAttributeInfo;

import org.ow2.petals.jmx.api.api.configuration.component.exception.ConfigurationComponentErrorException;
import org.ow2.petals.jmx.api.api.configuration.component.utils.AttributesHelper;
import org.ow2.petals.jmx.api.api.exception.AttributeErrorException;

/**
 * Interface of a JMX component associated to a JBI component configuration.
 * 
 * @see AttributesHelper
 * @author Christophe DENEUX - Linagora
 */
public interface AbstractConfigurationComponentClient {

    /**
     * Get an attribute value.
     * 
     * @param attribute
     *            The attribute name
     * @return The value of the given attribute
     * @throws AttributeErrorException
     */
    public Object getAttribute(final String attribute) throws AttributeErrorException;

    /**
     * Set an attribute value.
     * 
     * @param name
     *            The attribute name
     * @param value
     *            The attribute value to set
     * @throws AttributeErrorException
     */
    public void setAttribute(final String name, final Object value) throws AttributeErrorException;

    /**
     * Get attributes of configuration MBean
     * 
     * @return 
     * @throws ConfigurationComponentErrorException
     */
    public Map<MBeanAttributeInfo, Object> getConfigurationMBeanAttributes() throws ConfigurationComponentErrorException;

    /**
     * Set attributes of configuration MBean
     * 
     * @throws ConfigurationComponentErrorException
     */
    public void setConfigurationMBeanAttributes(final Map<MBeanAttributeInfo, Object> attributes)
            throws ConfigurationComponentErrorException;

}
