/**
 * Copyright (c) 2017-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api.configuration.component.utils;

import java.util.Map;

import javax.management.MBeanAttributeInfo;

import org.ow2.petals.jmx.api.api.configuration.component.AbstractConfigurationComponentClient;
import org.ow2.petals.jmx.api.api.configuration.component.exception.ConfigurationComponentErrorException;

/**
 * Some helpers to manipulate the attributes provided via {@link AbstractConfigurationComponentClient}.
 * 
 * @author Victor Noel - Linagora
 */
public class AttributesHelper {

    private AttributesHelper() {
        // utility class
    }

    public static Object convertParameterValueToObject(String name, String value,
            Map<MBeanAttributeInfo, Object> attributes) throws ConfigurationComponentErrorException {
        MBeanAttributeInfo info = findInfoByName(name, attributes);

        return info == null ? null : convertParameterValueToObject(info, value);
    }

    public static MBeanAttributeInfo findInfoByName(String name, Map<MBeanAttributeInfo, Object> attributes) {
        for (MBeanAttributeInfo info : attributes.keySet()) {
            if (name.equals(info.getName())) {
                return info;
            }
        }
        return null;
    }

    public static Object convertParameterValueToObject(MBeanAttributeInfo info, String value)
            throws ConfigurationComponentErrorException {

        String type = info.getType();

        try {
            if (String.class.getName().equals(type)) {
                return value;
            } else if (Integer.TYPE.getName().equals(type) || Integer.class.getName().equals(type)) {
                return Integer.valueOf(value);
            } else if (Long.TYPE.getName().equals(type) || Long.class.getName().equals(type)) {
                return Long.valueOf(value);
            } else if (Double.TYPE.getName().equals(type) || Double.class.getName().equals(type)) {
                return Double.valueOf(value);
            } else if (Float.TYPE.getName().equals(type) || Float.class.getName().equals(type)) {
                return Float.valueOf(value);
            } else if (Short.TYPE.getName().equals(type) || Short.class.getName().equals(type)) {
                return Short.valueOf(value);
            } else if (Byte.TYPE.getName().equals(type) || Byte.class.getName().equals(type)) {
                return Byte.valueOf(value);
            } else if (Boolean.TYPE.getName().equals(type) || Boolean.class.getName().equals(type)) {
                return Boolean.valueOf(value);
            } else {
                throw new ConfigurationComponentErrorException(
                        String.format("The type '%s' of parameter '%s' is not supported.", type, info.getName()));
            }
        } catch (final NumberFormatException nfe) {
            throw new ConfigurationComponentErrorException(
                    String.format("The value '%s' of the parameter '%s' is incorrect for type '%s'", value,
                            info.getName(), type),
                    nfe);
        }
    }
}
