/**
 * Copyright (c) 2013-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api.monitoring.component.framework;


/**
 * Bean as key identifying entries of metrics about service provider invocations.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ServiceProviderInvocationKey {

    /**
     * The field 'interface name'.
     */
    private final String interfaceName;

    /**
     * The field 'service name'.
     */
    private final String serviceName;

    /**
     * The field 'ooperation invoked'.
     */
    private final String operation;

    /**
     * The field 'mep' with which the web-service invocation is done.
     */
    private final String mep;

    /**
     * The field 'execution status'.
     */
    private final ServiceProviderInvocationStatus execStatus;

    /**
     * Creates a new key.
     * 
     * @param interfaceName
     *            Key part 'interface name'
     * @param serviceName
     *            Key part 'interface name'
     * @param operation
     *            Key part 'operation invoked'
     * @param mep
     *            Key part 'mep'
     * @param execStatus
     *            Key part 'execution status'
     */
    public ServiceProviderInvocationKey(final String interfaceName, final String serviceName,
            final String operation, final String mep,
            final ServiceProviderInvocationStatus execStatus) {
        super();
        this.interfaceName = interfaceName;
        this.serviceName = serviceName;
        this.operation = operation;
        this.mep = mep;
        this.execStatus = execStatus;
    }

    /**
     * @return Key part 'interface name'
     */
    public String getInterfaceName() {
        return this.interfaceName;
    }

    /**
     * @return Key part 'service name'
     */
    public String getServiceName() {
        return this.serviceName;
    }

    /**
     * @return Key part 'operation invoked'
     */
    public String getOperation() {
        return this.operation;
    }

    /**
     * @return Key part 'mep'
     */
    public String getMep() {
        return this.mep;
    }

    /**
     * @return Key part 'execution status'
     */
    public ServiceProviderInvocationStatus getExecStatus() {
        return this.execStatus;
    }

    // Generated by Eclipse
    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((execStatus == null) ? 0 : execStatus.hashCode());
        result = prime * result + ((interfaceName == null) ? 0 : interfaceName.hashCode());
        result = prime * result + ((mep == null) ? 0 : mep.hashCode());
        result = prime * result + ((operation == null) ? 0 : operation.hashCode());
        result = prime * result + ((serviceName == null) ? 0 : serviceName.hashCode());
        return result;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof ServiceProviderInvocationKey)) {
            return false;
        }
        ServiceProviderInvocationKey other = (ServiceProviderInvocationKey) obj;
        if (execStatus != other.execStatus) {
            return false;
        }
        if (interfaceName == null) {
            if (other.interfaceName != null) {
                return false;
            }
        } else if (!interfaceName.equals(other.interfaceName)) {
            return false;
        }
        if (mep == null) {
            if (other.mep != null) {
                return false;
            }
        } else if (!mep.equals(other.mep)) {
            return false;
        }
        if (operation == null) {
            if (other.operation != null) {
                return false;
            }
        } else if (!operation.equals(other.operation)) {
            return false;
        }
        if (serviceName == null) {
            if (other.serviceName != null) {
                return false;
            }
        } else if (!serviceName.equals(other.serviceName)) {
            return false;
        }
        return true;
    }

}
