/**
 * Copyright (c) 2013-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api.monitoring.component.framework;

/**
 * Available values for 'execution status' of service provider invocations
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public enum ServiceProviderInvocationStatus {
    SUCCEEDED(ServiceProviderInvocationStatusString.SUCCEEDED), PENDING(
            ServiceProviderInvocationStatusString.PENDING), FAULT(
            ServiceProviderInvocationStatusString.FAULT), ERROR(
            ServiceProviderInvocationStatusString.ERROR);

    private final String value;

    private ServiceProviderInvocationStatus(final String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    public static ServiceProviderInvocationStatus parse(final String value) {
        if (value != null) {
            for (final ServiceProviderInvocationStatus execStatus : ServiceProviderInvocationStatus.values()) {
                if (value.equalsIgnoreCase(execStatus.value)) {
                    return execStatus;
                }
            }
        }
        throw new IllegalArgumentException("Unknown service provider invocation status value: "
                + value);
    }
}