/**
 * Copyright (c) 2016-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api.monitoring.component.se.flowable;

import java.util.Map;

import org.ow2.petals.jmx.api.api.monitoring.component.framework.ComponentMonitoringServiceClient;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.exception.ComponentMonitoringServiceErrorException;
import org.ow2.petals.jmx.api.api.monitoring.object.ThreadPoolMetrics;

/**
 * Interface of the JMX service providing Petals SE Flowable monitoring metrics.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface SeFlowableMonitoringServiceClient extends ComponentMonitoringServiceClient {

    /**
     * @return Get the current metrics of the asynchronous job executor thread pool.
     * 
     * @throws ComponentMonitoringServiceErrorException
     */
    public ThreadPoolMetrics getAsyncExecutorThreadPoolMetrics() throws ComponentMonitoringServiceErrorException;

    /**
     * @return Get the current metrics of the database connection pool.
     * 
     * @throws ComponentMonitoringServiceErrorException
     */
    public DatabaseConnectionPoolMetrics getDatabaseConnectionPoolMetrics()
            throws ComponentMonitoringServiceErrorException;

    /**
     * <p>
     * Returns information on process definitions.
     * <p>
     * The map key is the process definition identifier. Each value of the map entry is an array of numbers where:
     * </p>
     * <ul>
     * <li>the 1st value is the suspension state: {@code 1} the process definition is suspended, {@code 0} it is not
     * suspended,
     * <li>
     * <li>the 2nd value is the number of active process instances,</li>
     * <li>the 3rd value is the number of suspended process instances,</li>
     * <li>the 4th value is the number of ended process instances.</li>
     * </ul>
     * 
     * @return Information about process definitions.
     * @throws ComponentMonitoringServiceErrorException
     */
    public Map<String, Long[]> getProcessDefinitions() throws ComponentMonitoringServiceErrorException;
}
