/**
 * Copyright (c) 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api.monitoring.component.soap;

/**
 * Bean as key identifying entries of metrics 'incoming web-service request
 * counts'.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class IncomingWsRequestKey {

    /**
     * The field 'web-service path'.
     */
    private final String wsPath;

    /**
     * The field 'web-service operation'.
     */
    private final String wsOperation;

    /**
     * The field 'ws-client IP address'.
     */
    private final String clientIpAddress;

    /**
     * The field 'execution status'.
     */
    private final WsRequestExecutionStatus execStatus;

    /**
     * Creates a new key.
     * 
     * @param wsPath
     *            Key part 'web-service path'
     * @param wsOperation
     *            Key part 'web-service operation'
     * @param clientIpAddress
     *            Key part 'ws-client IP address'
     * @param execStatus
     *            Key part 'execution status'
     */
    public IncomingWsRequestKey(final String wsPath, final String wsOperation,
            final String clientIpAddress,
 final WsRequestExecutionStatus execStatus) {
        super();
        this.wsPath = wsPath;
        this.wsOperation = wsOperation;
        this.clientIpAddress = clientIpAddress;
        this.execStatus = execStatus;
    }

    /**
     * @return Key part 'web-service path'
     */
    public String getWsPath() {
        return this.wsPath;
    }

    /**
     * @return Key part 'web-service operation'
     */
    public String getWsOperation() {
        return this.wsOperation;
    }

    /**
     * @return Key part 'ws-client IP address'
     */
    public String getClientIpAddress() {
        return this.clientIpAddress;
    }

    /**
     * @return Key part 'execution status'
     */
    public WsRequestExecutionStatus getExecStatus() {
        return this.execStatus;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#hashCode()
     */
    // Generated by Eclipse
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((clientIpAddress == null) ? 0 : clientIpAddress.hashCode());
        result = prime * result + ((execStatus == null) ? 0 : execStatus.hashCode());
        result = prime * result + ((wsOperation == null) ? 0 : wsOperation.hashCode());
        result = prime * result + ((wsPath == null) ? 0 : wsPath.hashCode());
        return result;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#equals(java.lang.Object)
     */
    // Generated by Eclipse
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof IncomingWsRequestKey)) {
            return false;
        }
        IncomingWsRequestKey other = (IncomingWsRequestKey) obj;
        if (clientIpAddress == null) {
            if (other.clientIpAddress != null) {
                return false;
            }
        } else if (!clientIpAddress.equals(other.clientIpAddress)) {
            return false;
        }
        if (execStatus != other.execStatus) {
            return false;
        }
        if (wsOperation == null) {
            if (other.wsOperation != null) {
                return false;
            }
        } else if (!wsOperation.equals(other.wsOperation)) {
            return false;
        }
        if (wsPath == null) {
            if (other.wsPath != null) {
                return false;
            }
        } else if (!wsPath.equals(other.wsPath)) {
            return false;
        }
        return true;
    }
}