/**
 * Copyright (c) 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api.monitoring.component.soap;

/**
 * Bean as key identifying entries of metrics 'outgoing web-service request
 * counts'.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class OutgoingWsRequestKey {

    /**
     * The field 'external web-service URL'.
     */
    private final String externalWsUrl;

    /**
     * The field 'web-service operation invoked'.
     */
    private final String wsOperation;

    /**
     * The field 'mep' with which the web-service invocation is done.
     */
    private final String mep;

    /**
     * The field 'execution status'.
     */
    private final WsRequestExecutionStatus execStatus;

    /**
     * Creates a new key.
     * 
     * @param externalWsUrl
     *            Key part 'external web-service URL'
     * @param wsOperation
     *            Key part 'web-service operation invoked'
     * @param mep
     *            Key part 'mep'
     * @param execStatus
     *            Key part 'execution status'
     */
    public OutgoingWsRequestKey(final String externalWsUrl, final String wsOperation,
            final String mep,
            final WsRequestExecutionStatus execStatus) {
        super();
        this.externalWsUrl = externalWsUrl;
        this.wsOperation = wsOperation;
        this.mep = mep;
        this.execStatus = execStatus;
    }

    /**
     * @return Key part 'external web-service URL'
     */
    public String getExternalWsUrl() {
        return this.externalWsUrl;
    }

    /**
     * @return Key part 'web-service operation invoked'
     */
    public String getWsOperation() {
        return this.wsOperation;
    }

    /**
     * @return Key part 'mep'
     */
    public String getMep() {
        return this.mep;
    }

    /**
     * @return Key part 'execution status'
     */
    public WsRequestExecutionStatus getExecStatus() {
        return this.execStatus;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#hashCode()
     */
    // Generated by Eclipse
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((mep == null) ? 0 : mep.hashCode());
        result = prime * result + ((execStatus == null) ? 0 : execStatus.hashCode());
        result = prime * result + ((wsOperation == null) ? 0 : wsOperation.hashCode());
        result = prime * result + ((externalWsUrl == null) ? 0 : externalWsUrl.hashCode());
        return result;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#equals(java.lang.Object)
     */
    // Generated by Eclipse
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof OutgoingWsRequestKey)) {
            return false;
        }
        OutgoingWsRequestKey other = (OutgoingWsRequestKey) obj;
        if (mep == null) {
            if (other.mep != null) {
                return false;
            }
        } else if (!mep.equals(other.mep)) {
            return false;
        }
        if (execStatus != other.execStatus) {
            return false;
        }
        if (wsOperation == null) {
            if (other.wsOperation != null) {
                return false;
            }
        } else if (!wsOperation.equals(other.wsOperation)) {
            return false;
        }
        if (externalWsUrl == null) {
            if (other.externalWsUrl != null) {
                return false;
            }
        } else if (!externalWsUrl.equals(other.externalWsUrl)) {
            return false;
        }
        return true;
    }
}
