/**
 * Copyright (c) 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api.monitoring.component.soap;

/**
 * Bean as key identifying entries of metrics 'ws-clients-pool-in-use'.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class WsClientPoolKey {

    /**
     * The field 'service'.
     */
    private final String service;

    /**
     * The field 'operation'.
     */
    private final String operation;

    /**
     * The field 'message exchange pattern'.
     */
    private final String mep;

    /**
     * Creates a new key.
     * 
     * @param service
     *            Key part 'service'
     * @param operation
     *            Key part 'operation'
     * @param mep
     *            Key part 'message exchange pattern'
     */
    public WsClientPoolKey(final String service, final String operation, final String mep) {
        super();
        this.service = service;
        this.operation = operation;
        this.mep = mep;
    }

    /**
     * @return Key part 'service'
     */
    public String getService() {
        return this.service;
    }

    /**
     * @return Key part 'operation'
     */
    public String getOperation() {
        return this.operation;
    }

    /**
     * @return Key part 'message exchange pattern'
     */
    public String getMep() {
        return this.mep;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#hashCode()
     */
    // Generated by Eclipse
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((mep == null) ? 0 : mep.hashCode());
        result = prime * result + ((operation == null) ? 0 : operation.hashCode());
        result = prime * result + ((service == null) ? 0 : service.hashCode());
        return result;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#equals(java.lang.Object)
     */
    // Generated by Eclipse
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof WsClientPoolKey)) {
            return false;
        }
        WsClientPoolKey other = (WsClientPoolKey) obj;
        if (mep == null) {
            if (other.mep != null) {
                return false;
            }
        } else if (!mep.equals(other.mep)) {
            return false;
        }
        if (operation == null) {
            if (other.operation != null) {
                return false;
            }
        } else if (!operation.equals(other.operation)) {
            return false;
        }
        if (service == null) {
            if (other.service != null) {
                return false;
            }
        } else if (!service.equals(other.service)) {
            return false;
        }
        return true;
    }
}