/**
 * Copyright (c) 2013-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api.monitoring.defect;

import org.ow2.petals.jmx.api.api.monitoring.defect.exception.DefectEmitterDoesNotExistsException;
import org.ow2.petals.jmx.api.api.monitoring.defect.exception.DefectListenerException;
import org.ow2.petals.jmx.api.api.monitoring.defect.exception.NoDefectListenerException;

/**
 * Interface of service listening defects
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public interface DefectListenerService {

    /**
     * Subscribe to the defects
     * 
     * @param defectListener
     *            Defect listener
     * @param defectFilter
     *            Defect filter. No filter applied if null.
     * @throws DefectListenerException
     * @throws DefectEmitterDoesNotExistsException
     */
    public void subscribe(final DefectListener defectListener, final DefectFilter defectFilter)
            throws DefectListenerException, DefectEmitterDoesNotExistsException;

    /**
     * Unsubscribe from defects
     * 
     * @throws NoDefectListenerException
     * @throws DefectEmitterDoesNotExistsException
     * @throws DefectListenerException
     */
    public void unsubscribe() throws NoDefectListenerException,
            DefectEmitterDoesNotExistsException, DefectListenerException;

}
