/**
 * Copyright (c) 2013-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api.monitoring.defect.exception;

/**
 * The defect emitter does not exist
 * 
 * @author Christophe DENEUX - Linagora
 *
 */
public class DefectEmitterDoesNotExistsException extends DefectException {

    private static final long serialVersionUID = -2097322282389256818L;

    private static final String MESSAGE_TEMPLATE = "The defect emitter '%s' does not exist.";

    /**
     * The defect emitter name that does not exist
     */
    private final String defectEmitterName;

    public DefectEmitterDoesNotExistsException(final String defectEmitterName) {
        super(String.format(MESSAGE_TEMPLATE, defectEmitterName));
        this.defectEmitterName = defectEmitterName;
    }

    public DefectEmitterDoesNotExistsException(final Throwable cause, final String defectEmitterName) {
        super(String.format(MESSAGE_TEMPLATE, defectEmitterName), cause);
        this.defectEmitterName = defectEmitterName;
    }

    /**
     * @return The defect emitter name that does not exist
     */
    public String getDefectEmitterName() {
        return this.defectEmitterName;
    }

}
